@@ -129,14 +129,6 @@ def pkgs_handling_extra_modaliases(modaliaslist):
 Look up package-hardware mappings from git and local file
 """
     thepkgs = {}
-    url = "https://anonscm.debian.org/cgit/collab-maint/isenkram.git/plain/modaliases"
-    try:
-        f = urllib2.urlopen(url)
-        if f.getcode() == 200:
-            check_packages_file(thepkgs, f, modaliaslist)
-    except IOError, e:
-        if errno.ENOENT == e.errno:  # Most likely lack network connection
-            pass
     try:
         try:
             f = open("modaliases")
